@@ -64,6 +64,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     "weight" in include and parse_weight(p, selector=sel)
     "brand" in include and parse_brand(p, selector=sel)
     should_price() and parse_price(p, selector=sel)
+    "available" in include and parse_available(p, selector=sel)
     "in_stock" in include and parse_in_stock(p, selector=sel)
     "stock" in include and parse_stock(p, selector=sel)
     should_ship_day() and parse_ship_day(p, selector=sel)
@@ -171,6 +172,19 @@ def parse_price(p: Product, selector: parsel.Selector = None):
         p.price_max = float(prices[1])
 
 
+def parse_available(p: Product, selector: parsel.Selector = None):
+    available = selector.xpath("//div[@id='availability']/span/text()").get()
+    if available is None:
+        p.available = None
+        return
+
+    available = available.strip()
+    if available == "Currently unavailable.":
+        p.available = False
+    else:
+        p.available = True
+
+
 def parse_in_stock(p: Product, selector: parsel.Selector = None):
     in_stock = selector.xpath("//div[@id='availability']/span/text()").get()
     if in_stock is None:
